Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/async_simplebutton_test.py
    :caption: examples/async_simplebutton_test.py
    :linenos:

.. literalinclude:: ../examples/async_button_test.py
    :caption: examples/async_button_test.py
    :linenos:
